@@ -16,6 +16,8 @@ typedef struct circ_node
 	int num_nodes;
 	struct circ_node** nodes;
 	int edge_num;
+    int geom_type;
+    POINT2D pt_outside;
 	POINT2D* p1;
 	POINT2D* p2;
 } CIRC_NODE;
@@ -26,5 +28,6 @@ void circ_tree_free(CIRC_NODE* node);
 int circ_tree_contains_point(const CIRC_NODE* node, const POINT2D* pt, const POINT2D* pt_outside, int* on_boundary);
 double circ_tree_distance_tree(const CIRC_NODE* n1, const CIRC_NODE* n2, const SPHEROID *spheroid, double threshold);
 CIRC_NODE* lwgeom_calculate_circ_tree(const LWGEOM* lwgeom);
+int circ_tree_get_point(const CIRC_NODE* node, POINT2D* pt);
 
 #endif /* _LWGEODETIC_TREE_H */
\ No newline at end of file
