@@ -497,7 +497,7 @@ nd_box_init_bounds(ND_BOX *a)
 	for ( d = 0; d < ND_DIMS; d++ )
 	{
 		a->min[d] = FLT_MAX;
-		a->max[d] = FLT_MIN;
+		a->max[d] = -1 * FLT_MAX;
 	}
 	return TRUE;
 }
@@ -753,16 +753,18 @@ nd_box_array_distribution(const ND_BOX **nd_boxes, int num_boxes, const ND_BOX *
 
 		/* How dispersed is the distribution of features across bins? */
 		range = range_quintile(counts, num_bins);
+
 #if POSTGIS_DEBUG_LEVEL >= 3
 		average = avg(counts, num_bins);
 		sdev = stddev(counts, num_bins);
 		sdev_ratio = sdev/average;
-#endif
-		
+
 		POSTGIS_DEBUGF(3, " dimension %d: range = %d", d, range);
 		POSTGIS_DEBUGF(3, " dimension %d: average = %.6g", d, average);
 		POSTGIS_DEBUGF(3, " dimension %d: stddev = %.6g", d, sdev);
 		POSTGIS_DEBUGF(3, " dimension %d: stddev_ratio = %.6g", d, sdev_ratio);
+#endif
+		
 		distribution[d] = range;
 	}
 	
@@ -1074,6 +1076,10 @@ estimate_join_selectivity(const ND_STATS *s1, const ND_STATS *s2)
 	 * number of rows that can be returned.
 	 */
 	selectivity = val / ntuples_max;
+
+    /* Guard against over-estimates :) */
+    if ( selectivity > 1.0 ) 
+        selectivity = 1.0;
 	
 	return selectivity;
 }
