@@ -1,15 +1,23 @@
+/**********************************************************************
+ *
+ * PostGIS - Spatial Types for PostgreSQL
+ * http://postgis.refractions.net
+ *
+ * Copyright (C) 2006 Refractions Research Inc.
+ *
+ * This is free software; you can redistribute and/or modify it under
+ * the terms of the GNU General Public Licence. See the COPYING file.
+ *
+ **********************************************************************/
+
 #include "postgres.h"
 #include "access/xact.h"
 #include "executor/spi.h"       /* this is what you need to work with SPI */
 #include "commands/trigger.h"   /* ... and triggers */
 #include "utils/lsyscache.h"	/* for get_namespace_name() */
-
-#include "lwgeom_pg.h"
-
-#if POSTGIS_PGSQL_VERSION >= 92
 #include "utils/rel.h"
-#endif
-
+#include "../postgis_config.h"
+#include "lwgeom_pg.h"
 
 #define ABORT_ON_AUTH_FAILURE 1
 
