@@ -9,8 +9,10 @@
 #include "utils/elog.h"
 #include "utils/geo_decls.h"
 
+#include "../postgis_config.h"
 #include "lwgeom_pg.h"
 #include "liblwgeom.h"
+#include "liblwgeom_internal.h"
 
 #include <math.h>
 #include <float.h>
@@ -24,12 +26,10 @@
 /* forward defs */
 Datum BOX3D_in(PG_FUNCTION_ARGS);
 Datum BOX3D_out(PG_FUNCTION_ARGS);
-Datum BOX3D_extent_out(PG_FUNCTION_ARGS);
-Datum BOX3D_extent_to_BOX3D(PG_FUNCTION_ARGS);
 Datum LWGEOM_to_BOX3D(PG_FUNCTION_ARGS);
 Datum BOX3D_to_LWGEOM(PG_FUNCTION_ARGS);
 Datum BOX3D_expand(PG_FUNCTION_ARGS);
-Datum BOX3D_to_BOX2DFLOAT4(PG_FUNCTION_ARGS);
+Datum BOX3D_to_BOX2D(PG_FUNCTION_ARGS);
 Datum BOX3D_to_BOX(PG_FUNCTION_ARGS);
 Datum BOX3D_xmin(PG_FUNCTION_ARGS);
 Datum BOX3D_ymin(PG_FUNCTION_ARGS);
@@ -101,6 +101,7 @@ Datum BOX3D_in(PG_FUNCTION_ARGS)
 		box->zmin = box->zmax;
 		box->zmax = tmp;
 	}
+	box->srid = SRID_UNKNOWN;
 	PG_RETURN_POINTER(box);
 }
 
@@ -121,7 +122,7 @@ Datum BOX3D_out(PG_FUNCTION_ARGS)
 	if (bbox == NULL)
 	{
 		result = palloc(5);
-		strcpy(result, "NULL");
+		strcat(result,"NULL");
 		PG_RETURN_CSTRING(result);
 	}
 
@@ -138,64 +139,27 @@ Datum BOX3D_out(PG_FUNCTION_ARGS)
 	PG_RETURN_CSTRING(result);
 }
 
-/**
- *  Takes an internal rep of a BOX3D and returns a string rep.
- *  but beginning with BOX(...) and with only 2 dimensions. This
- *  is a temporary hack to allow ST_Extent() to return a result
- *  with the precision of BOX2DFLOAT4 but with the BOX2DFLOAT4
- *  output format.
- *
- *  example:
- *     "BOX(xmin ymin, xmax ymax)"
- */
-PG_FUNCTION_INFO_V1(BOX3D_extent_out);
-Datum BOX3D_extent_out(PG_FUNCTION_ARGS)
-{
-	BOX3D  *bbox = (BOX3D *) PG_GETARG_POINTER(0);
-	int size;
-	char *result;
 
-	if (bbox == NULL)
-	{
-		result = palloc(5);
-		strcat(result,"NULL");
-		PG_RETURN_CSTRING(result);
-	}
-
-
-	/*double digits+ "BOX3D"+ "()" + commas +null */
-	size = MAX_DIGS_DOUBLE*6+5+2+4+5+1;
-
-	result = (char *) palloc(size);
-
-	sprintf(result, "BOX(%.15g %.15g,%.15g %.15g)",
-	        bbox->xmin, bbox->ymin,
-	        bbox->xmax,bbox->ymax);
-
-	PG_RETURN_CSTRING(result);
-}
-
-PG_FUNCTION_INFO_V1(BOX3D_extent_to_BOX3D);
-Datum BOX3D_extent_to_BOX3D(PG_FUNCTION_ARGS)
+PG_FUNCTION_INFO_V1(BOX3D_to_BOX2D);
+Datum BOX3D_to_BOX2D(PG_FUNCTION_ARGS)
 {
 	BOX3D *in = (BOX3D *)PG_GETARG_POINTER(0);
-	BOX3D *out = palloc(sizeof(BOX3D));
-	out->xmin = in->xmin;
-	out->xmax = in->xmax;
-	out->ymin = in->ymin;
-	out->ymax = in->ymax;
-	out->zmin = in->zmin;
-	out->zmax = in->zmax;
-
+	GBOX *out = box3d_to_gbox(in);
 	PG_RETURN_POINTER(out);
 }
 
-PG_FUNCTION_INFO_V1(BOX3D_to_BOX2DFLOAT4);
-Datum BOX3D_to_BOX2DFLOAT4(PG_FUNCTION_ARGS)
+static void
+box3d_to_box_p(BOX3D *box, BOX *out)
 {
-	BOX3D *in = (BOX3D *)PG_GETARG_POINTER(0);
-	BOX2DFLOAT4 *out = box3d_to_box2df(in);
-	PG_RETURN_POINTER(out);
+#if PARANOIA_LEVEL > 0
+	if (box == NULL) return;
+#endif
+
+	out->low.x = box->xmin;
+	out->low.y = box->ymin;
+
+	out->high.x = box->xmax;
+	out->high.y = box->ymax;
 }
 
 PG_FUNCTION_INFO_V1(BOX3D_to_BOX);
@@ -208,14 +172,14 @@ Datum BOX3D_to_BOX(PG_FUNCTION_ARGS)
 	PG_RETURN_POINTER(box);
 }
 
+
 PG_FUNCTION_INFO_V1(BOX3D_to_LWGEOM);
 Datum BOX3D_to_LWGEOM(PG_FUNCTION_ARGS)
 {
 	BOX3D *box = (BOX3D *)PG_GETARG_POINTER(0);
 	POINTARRAY *pa;
-	int wantbbox = 0;
-	PG_LWGEOM *result;
-	uchar *ser;
+	GSERIALIZED *result;
+	POINT4D pt;
 
 
 	/**
@@ -229,62 +193,57 @@ Datum BOX3D_to_LWGEOM(PG_FUNCTION_ARGS)
 	 *     - Otherwise return a POLYGON
 	 */
 
-	if (box->xmin == box->xmax &&
-	        box->ymin == box->ymax)
+	pa = ptarray_construct_empty(0, 0, 5);
+
+	if ( (box->xmin == box->xmax) && (box->ymin == box->ymax) )
 	{
-		/* Construct and serialize point */
-		LWPOINT *point = make_lwpoint2d(-1, box->xmin, box->ymin);
-		ser = lwpoint_serialize(point);
+		LWPOINT *lwpt = lwpoint_construct(SRID_UNKNOWN, NULL, pa);
+
+		pt.x = box->xmin;
+		pt.y = box->ymin;
+		ptarray_append_point(pa, &pt, LW_TRUE);
+
+		result = geometry_serialize(lwpoint_as_lwgeom(lwpt));
 	}
 	else if (box->xmin == box->xmax ||
 	         box->ymin == box->ymax)
 	{
-		LWLINE *line;
-		POINT2D *pts = palloc(sizeof(POINT2D)*2);
+		LWLINE *lwline = lwline_construct(SRID_UNKNOWN, NULL, pa);
 
-		/* Assign coordinates to POINT2D array */
-		pts[0].x = box->xmin;
-		pts[0].y = box->ymin;
-		pts[1].x = box->xmax;
-		pts[1].y = box->ymax;
+		pt.x = box->xmin;
+		pt.y = box->ymin;
+		ptarray_append_point(pa, &pt, LW_TRUE);
+		pt.x = box->xmax;
+		pt.y = box->ymax;
+		ptarray_append_point(pa, &pt, LW_TRUE);
 
-		/* Construct point array */
-		pa = pointArray_construct((uchar *)pts, 0, 0, 2);
-
-		/* Construct and serialize linestring */
-		line = lwline_construct(-1, NULL, pa);
-		ser = lwline_serialize(line);
+		result = geometry_serialize(lwline_as_lwgeom(lwline));
 	}
 	else
 	{
-		LWPOLY *poly;
-		POINT2D *pts = palloc(sizeof(POINT2D)*5);
+		LWPOLY *lwpoly = lwpoly_construct(SRID_UNKNOWN, NULL, 1, &pa);
 
-		/* Assign coordinates to POINT2D array */
-		pts[0].x = box->xmin;
-		pts[0].y = box->ymin;
-		pts[1].x = box->xmin;
-		pts[1].y = box->ymax;
-		pts[2].x = box->xmax;
-		pts[2].y = box->ymax;
-		pts[3].x = box->xmax;
-		pts[3].y = box->ymin;
-		pts[4].x = box->xmin;
-		pts[4].y = box->ymin;
+		pt.x = box->xmin;
+		pt.y = box->ymin;
+		ptarray_append_point(pa, &pt, LW_TRUE);
+		pt.x = box->xmin;
+		pt.y = box->ymax;
+		ptarray_append_point(pa, &pt, LW_TRUE);
+		pt.x = box->xmax;
+		pt.y = box->ymax;
+		ptarray_append_point(pa, &pt, LW_TRUE);
+		pt.x = box->xmax;
+		pt.y = box->ymin;
+		ptarray_append_point(pa, &pt, LW_TRUE);
+		pt.x = box->xmin;
+		pt.y = box->ymin;
+		ptarray_append_point(pa, &pt, LW_TRUE);
 
-		/* Construct point array */
-		pa = pointArray_construct((uchar *)pts, 0, 0, 5);
-
-		/* Construct polygon */
-		poly = lwpoly_construct(-1, NULL, 1, &pa);
-
-		/* Serialize polygon */
-		ser = lwpoly_serialize(poly);
+		result = geometry_serialize(lwpoly_as_lwgeom(lwpoly));
+		
 	}
 
-	/* Construct PG_LWGEOM  */
-	result = PG_LWGEOM_construct(ser, -1, wantbbox);
-
+	gserialized_set_srid(result, box->srid);
 	PG_RETURN_POINTER(result);
 }
 
@@ -315,7 +274,7 @@ Datum BOX3D_expand(PG_FUNCTION_ARGS)
 }
 
 /**
- * convert a PG_LWGEOM to BOX3D
+ * convert a GSERIALIZED to BOX3D
  *
  * NOTE: the bounding box is *always* recomputed as the cache
  * is a box2d, not a box3d...
@@ -324,12 +283,19 @@ Datum BOX3D_expand(PG_FUNCTION_ARGS)
 PG_FUNCTION_INFO_V1(LWGEOM_to_BOX3D);
 Datum LWGEOM_to_BOX3D(PG_FUNCTION_ARGS)
 {
-	PG_LWGEOM *lwgeom = (PG_LWGEOM *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *geom = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	LWGEOM *lwgeom = lwgeom_from_gserialized(geom);
+	GBOX gbox;
 	BOX3D *result;
+	int rv = lwgeom_calculate_gbox(lwgeom, &gbox);
 
-	result = compute_serialized_box3d(SERIALIZED_FORM(lwgeom));
-	if ( ! result ) PG_RETURN_NULL();
+	if ( rv == LW_FAILURE )
+		PG_RETURN_NULL();
+		
+	result = box3d_from_gbox(&gbox);
+	result->srid = lwgeom->srid;
 
+	lwgeom_free(lwgeom);
 	PG_RETURN_POINTER(result);
 }
 
@@ -337,123 +303,133 @@ PG_FUNCTION_INFO_V1(BOX3D_xmin);
 Datum BOX3D_xmin(PG_FUNCTION_ARGS)
 {
 	BOX3D *box = (BOX3D *)PG_GETARG_POINTER(0);
-	PG_RETURN_FLOAT8(LWGEOM_Mind(box->xmin, box->xmax));
+	PG_RETURN_FLOAT8(Min(box->xmin, box->xmax));
 }
 
 PG_FUNCTION_INFO_V1(BOX3D_ymin);
 Datum BOX3D_ymin(PG_FUNCTION_ARGS)
 {
 	BOX3D *box = (BOX3D *)PG_GETARG_POINTER(0);
-	PG_RETURN_FLOAT8(LWGEOM_Mind(box->ymin, box->ymax));
+	PG_RETURN_FLOAT8(Min(box->ymin, box->ymax));
 }
 
 PG_FUNCTION_INFO_V1(BOX3D_zmin);
 Datum BOX3D_zmin(PG_FUNCTION_ARGS)
 {
 	BOX3D *box = (BOX3D *)PG_GETARG_POINTER(0);
-	PG_RETURN_FLOAT8(LWGEOM_Mind(box->zmin, box->zmax));
+	PG_RETURN_FLOAT8(Min(box->zmin, box->zmax));
 }
 
 PG_FUNCTION_INFO_V1(BOX3D_xmax);
 Datum BOX3D_xmax(PG_FUNCTION_ARGS)
 {
 	BOX3D *box = (BOX3D *)PG_GETARG_POINTER(0);
-	PG_RETURN_FLOAT8(LWGEOM_Maxd(box->xmin, box->xmax));
+	PG_RETURN_FLOAT8(Max(box->xmin, box->xmax));
 }
 
 PG_FUNCTION_INFO_V1(BOX3D_ymax);
 Datum BOX3D_ymax(PG_FUNCTION_ARGS)
 {
 	BOX3D *box = (BOX3D *)PG_GETARG_POINTER(0);
-	PG_RETURN_FLOAT8(LWGEOM_Maxd(box->ymin, box->ymax));
+	PG_RETURN_FLOAT8(Max(box->ymin, box->ymax));
 }
 
 PG_FUNCTION_INFO_V1(BOX3D_zmax);
 Datum BOX3D_zmax(PG_FUNCTION_ARGS)
 {
 	BOX3D *box = (BOX3D *)PG_GETARG_POINTER(0);
-	PG_RETURN_FLOAT8(LWGEOM_Maxd(box->zmin, box->zmax));
+	PG_RETURN_FLOAT8(Max(box->zmin, box->zmax));
 }
 
-
+/**
+* Used in the ST_Extent and ST_Extent3D aggregates, does not read the 
+* serialized cached bounding box (since that is floating point)
+* but calculates the box in full from the underlying geometry.
+*/
 PG_FUNCTION_INFO_V1(BOX3D_combine);
 Datum BOX3D_combine(PG_FUNCTION_ARGS)
 {
-	Pointer box3d_ptr = PG_GETARG_POINTER(0);
-	Pointer geom_ptr = PG_GETARG_POINTER(1);
-	BOX3D *a,*b;
-	PG_LWGEOM *lwgeom;
-	BOX3D *box, *result;
+	BOX3D *box = (BOX3D*)PG_GETARG_POINTER(0);
+	GSERIALIZED *geom = PG_ARGISNULL(1) ? NULL : (GSERIALIZED*)PG_DETOAST_DATUM(PG_GETARG_POINTER(1));
+	LWGEOM *lwgeom = NULL;
+	BOX3D *result = NULL;
+	GBOX gbox;
+	int32_t srid;
+	int rv;
 
-	if  ( (box3d_ptr == NULL) && (geom_ptr == NULL) )
-	{
+	/* Can't do anything with null inputs */
+	if  ( (box == NULL) && (geom == NULL) )
 		PG_RETURN_NULL();
-	}
 
-	result = (BOX3D *)palloc(sizeof(BOX3D));
-
-	if (box3d_ptr == NULL)
+	/* Null geometry but non-null box, return the box */
+	if (geom == NULL)
 	{
-		lwgeom = (PG_LWGEOM *)PG_DETOAST_DATUM(PG_GETARG_DATUM(1));
-		box = compute_serialized_box3d(SERIALIZED_FORM(lwgeom));
-		if ( ! box )
-		{
-			PG_FREE_IF_COPY(lwgeom, 1);
-			PG_RETURN_NULL(); /* must be the empty geom */
-		}
+		result = palloc(sizeof(BOX3D));
 		memcpy(result, box, sizeof(BOX3D));
 		PG_RETURN_POINTER(result);
 	}
 
-	/* combine_bbox(BOX3D, null) => BOX3D */
-	if (geom_ptr == NULL)
+	/* Deserialize geometry and *calculate* the box */
+	/* We can't use the cached box because it's float, we *must* calculate */
+	lwgeom = lwgeom_from_gserialized(geom);
+	srid = lwgeom->srid;
+	rv = lwgeom_calculate_gbox(lwgeom, &gbox);
+	lwgeom_free(lwgeom);
+
+	/* If we couldn't calculate the box, return what we know */
+	if ( rv == LW_FAILURE )
 	{
-		memcpy(result, (char *)PG_GETARG_DATUM(0), sizeof(BOX3D));
+		PG_FREE_IF_COPY(geom, 1);
+		/* No geom box, no input box, so null return */
+		if ( box == NULL )
+			PG_RETURN_NULL();
+		result = palloc(sizeof(BOX3D));
+		memcpy(result, box, sizeof(BOX3D));
 		PG_RETURN_POINTER(result);
 	}
 
-	lwgeom = (PG_LWGEOM *)PG_DETOAST_DATUM(PG_GETARG_DATUM(1));
-	box = compute_serialized_box3d(SERIALIZED_FORM(lwgeom));
-	if ( ! box ) /* must be the empty geom */
+	/* Null box and non-null geometry, just return the geometry box */
+	if ( box == NULL )
 	{
-		PG_FREE_IF_COPY(lwgeom, 1);
-		memcpy(result, (char *)PG_GETARG_DATUM(0), sizeof(BOX3D));
+		PG_FREE_IF_COPY(geom, 1);
+		result = box3d_from_gbox(&gbox);
+		result->srid = srid;
 		PG_RETURN_POINTER(result);
 	}
 
-	a = (BOX3D *)PG_GETARG_DATUM(0);
-	b = box;
-
-	result->xmax = LWGEOM_Maxd(a->xmax, b->xmax);
-	result->ymax = LWGEOM_Maxd(a->ymax, b->ymax);
-	result->zmax = LWGEOM_Maxd(a->zmax, b->zmax);
-	result->xmin = LWGEOM_Mind(a->xmin, b->xmin);
-	result->ymin = LWGEOM_Mind(a->ymin, b->ymin);
-	result->zmin = LWGEOM_Mind(a->zmin, b->zmin);
+	result = palloc(sizeof(BOX3D));
+	result->xmax = Max(box->xmax, gbox.xmax);
+	result->ymax = Max(box->ymax, gbox.ymax);
+	result->zmax = Max(box->zmax, gbox.zmax);
+	result->xmin = Min(box->xmin, gbox.xmin);
+	result->ymin = Min(box->ymin, gbox.ymin);
+	result->zmin = Min(box->zmin, gbox.zmin);
+	result->srid = srid;
 
+	PG_FREE_IF_COPY(geom, 1);
 	PG_RETURN_POINTER(result);
 }
 
 PG_FUNCTION_INFO_V1(BOX3D_construct);
 Datum BOX3D_construct(PG_FUNCTION_ARGS)
 {
-	PG_LWGEOM *min = (PG_LWGEOM *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
-	PG_LWGEOM *max = (PG_LWGEOM *)PG_DETOAST_DATUM(PG_GETARG_DATUM(1));
+	GSERIALIZED *min = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *max = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(1));
 	BOX3D *result = palloc(sizeof(BOX3D));
 	LWGEOM *minpoint, *maxpoint;
 	POINT3DZ minp, maxp;
 
-	minpoint = lwgeom_deserialize(SERIALIZED_FORM(min));
-	maxpoint = lwgeom_deserialize(SERIALIZED_FORM(max));
+	minpoint = lwgeom_from_gserialized(min);
+	maxpoint = lwgeom_from_gserialized(max);
 
-	if ( TYPE_GETTYPE(minpoint->type) != POINTTYPE ||
-	        TYPE_GETTYPE(maxpoint->type) != POINTTYPE )
+	if ( minpoint->type != POINTTYPE ||
+	     maxpoint->type != POINTTYPE )
 	{
 		elog(ERROR, "BOX3D_construct: args must be points");
 		PG_RETURN_NULL();
 	}
 
-	errorIfSRIDMismatch(minpoint->SRID, maxpoint->SRID);
+	error_if_srid_mismatch(minpoint->srid, maxpoint->srid);
 
 	getPoint3dz_p(((LWPOINT *)minpoint)->point, 0, &minp);
 	getPoint3dz_p(((LWPOINT *)maxpoint)->point, 0, &maxp);
@@ -466,24 +442,7 @@ Datum BOX3D_construct(PG_FUNCTION_ARGS)
 	result->ymin = minp.y;
 	result->zmin = minp.z;
 
+	result->srid = minpoint->srid;
+
 	PG_RETURN_POINTER(result);
 }
-
-/** min(a,b) */
-double
-LWGEOM_Mind(double a, double b)
-{
-	if (a<b)
-		return a;
-	return b;
-}
-
-/** max(a,b) */
-double
-LWGEOM_Maxd(double a, double b)
-{
-	if (b>a)
-		return b;
-	return a;
-}
-
