@@ -1,24 +1,253 @@
 /**********************************************************************
- * $Id: lwgeom_functions_lrs.c 10612 2012-10-31 21:16:08Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.refractions.net
- * Copyright 2001-2005 Refractions Research Inc.
+ *
+ * Copyright (C) 2001-2005 Refractions Research Inc.
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU General Public Licence. See the COPYING file.
  *
  **********************************************************************/
 
+#include <math.h>
+
 #include "postgres.h"
 #include "fmgr.h"
+
+#include "../postgis_config.h"
 #include "liblwgeom.h"
 #include "lwgeom_pg.h"
-#include "math.h"
 
-
-Datum LWGEOM_locate_between_m(PG_FUNCTION_ARGS);
+/*
+* Add a measure dimension to a line, interpolating linearly from the
+* start value to the end value.
+* ST_AddMeasure(Geometry, StartMeasure, EndMeasure) returns Geometry
+*/
 Datum ST_AddMeasure(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(ST_AddMeasure);
+Datum ST_AddMeasure(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED *gin = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *gout;
+	double start_measure = PG_GETARG_FLOAT8(1);
+	double end_measure = PG_GETARG_FLOAT8(2);
+	LWGEOM *lwin, *lwout;
+	int type = gserialized_get_type(gin);
+
+	/* Raise an error if input is not a linestring or multilinestring */
+	if ( type != LINETYPE && type != MULTILINETYPE )
+	{
+		lwerror("Only LINESTRING and MULTILINESTRING are supported");
+		PG_RETURN_NULL();
+	}
+
+	lwin = lwgeom_from_gserialized(gin);
+	if ( type == LINETYPE )
+		lwout = (LWGEOM*)lwline_measured_from_lwline((LWLINE*)lwin, start_measure, end_measure);
+	else
+		lwout = (LWGEOM*)lwmline_measured_from_lwmline((LWMLINE*)lwin, start_measure, end_measure);
+
+	lwgeom_free(lwin);
+
+	if ( lwout == NULL )
+		PG_RETURN_NULL();
+
+	gout = geometry_serialize(lwout);
+	lwgeom_free(lwout);
+
+	PG_RETURN_POINTER(gout);
+}
+
+
+/*
+* Locate a point along a feature based on a measure value.
+* ST_LocateAlong(Geometry, Measure, [Offset]) returns Geometry
+*/
+Datum ST_LocateAlong(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(ST_LocateAlong);
+Datum ST_LocateAlong(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED *gin = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *gout;
+	LWGEOM *lwin = NULL, *lwout = NULL;
+	double measure = PG_GETARG_FLOAT8(1);
+	double offset = PG_GETARG_FLOAT8(2);;
+
+	lwin = lwgeom_from_gserialized(gin);
+	lwout = lwgeom_locate_along(lwin, measure, offset);
+	lwgeom_free(lwin);
+	PG_FREE_IF_COPY(gin, 0);
+
+	if ( ! lwout )
+		PG_RETURN_NULL();
+
+	gout = geometry_serialize(lwout);
+	lwgeom_free(lwout);
+
+	PG_RETURN_POINTER(gout);
+}
+
+
+/*
+* Locate the portion of a line between the specified measures
+*/
+Datum ST_LocateBetween(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(ST_LocateBetween);
+Datum ST_LocateBetween(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED *geom_in = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	double from = PG_GETARG_FLOAT8(1);
+	double to = PG_GETARG_FLOAT8(2);
+	double offset = PG_GETARG_FLOAT8(3);
+	LWCOLLECTION *geom_out = NULL;
+	LWGEOM *line_in = NULL;
+	static char ordinate = 'M'; /* M */
+
+	if ( ! gserialized_has_m(geom_in) )
+	{
+		elog(ERROR,"This function only accepts geometries that have an M dimension.");
+		PG_RETURN_NULL();
+	}
+
+	/* This should be a call to ST_LocateAlong! */
+	if ( to == from )
+	{
+		PG_RETURN_DATUM(DirectFunctionCall3(ST_LocateAlong, PG_GETARG_DATUM(0), PG_GETARG_DATUM(1), PG_GETARG_DATUM(3)));
+	}
+
+	line_in = lwgeom_from_gserialized(geom_in);
+	geom_out = lwgeom_clip_to_ordinate_range(line_in,  ordinate, from, to, offset);	
+	lwgeom_free(line_in);
+	PG_FREE_IF_COPY(geom_in, 0);
+
+	if ( ! geom_out )
+	{
+		elog(ERROR,"lwline_clip_to_ordinate_range returned null");
+		PG_RETURN_NULL();
+	}
+
+	PG_RETURN_POINTER(geometry_serialize((LWGEOM*)geom_out));
+}
+
+/*
+* Locate the portion of a line between the specified elevations
+*/
+Datum ST_LocateBetweenElevations(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(ST_LocateBetweenElevations);
+Datum ST_LocateBetweenElevations(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED *geom_in = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	double from = PG_GETARG_FLOAT8(1);
+	double to = PG_GETARG_FLOAT8(2);
+	LWCOLLECTION *geom_out = NULL;
+	LWGEOM *line_in = NULL;
+	static char ordinate = 'Z'; /* Z */
+	static double offset = 0.0;
+
+	if ( ! gserialized_has_z(geom_in) )
+	{
+		elog(ERROR,"This function only accepts LINESTRING or MULTILINESTRING with Z dimensions.");
+		PG_RETURN_NULL();
+	}
+
+	line_in = lwgeom_from_gserialized(geom_in);
+	geom_out = lwgeom_clip_to_ordinate_range(line_in,  ordinate, from, to, offset);	
+	lwgeom_free(line_in);
+	PG_FREE_IF_COPY(geom_in, 0);
+
+	if ( ! geom_out )
+	{
+		elog(ERROR,"lwline_clip_to_ordinate_range returned null");
+		PG_RETURN_NULL();
+	}
+
+	PG_RETURN_POINTER(geometry_serialize((LWGEOM*)geom_out));
+}
+
+
+Datum ST_InterpolatePoint(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(ST_InterpolatePoint);
+Datum ST_InterpolatePoint(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED *gser_line = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *gser_point = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(1));
+	LWGEOM *lwline;
+	LWPOINT *lwpoint;
+
+	if ( gserialized_get_type(gser_line) != LINETYPE )
+	{
+		elog(ERROR,"ST_InterpolatePoint: 1st argument isn't a line");
+		PG_RETURN_NULL();
+	}
+	if ( gserialized_get_type(gser_point) != POINTTYPE )
+	{
+		elog(ERROR,"ST_InterpolatePoint: 2st argument isn't a point");
+		PG_RETURN_NULL();
+	}
+	if ( gserialized_get_srid(gser_line) != gserialized_get_srid(gser_point) )
+	{
+		elog(ERROR, "Operation on two geometries with different SRIDs");
+		PG_RETURN_NULL();
+	}
+	if ( ! gserialized_has_m(gser_line) )
+	{
+		elog(ERROR,"ST_InterpolatePoint only accepts geometries that have an M dimension");
+		PG_RETURN_NULL();
+	}
+	
+	lwpoint = lwgeom_as_lwpoint(lwgeom_from_gserialized(gser_point));
+	lwline = lwgeom_from_gserialized(gser_line);
+	
+	PG_RETURN_FLOAT8(lwgeom_interpolate_point(lwline, lwpoint));
+}
+
+
+Datum LWGEOM_line_locate_point(PG_FUNCTION_ARGS);
+PG_FUNCTION_INFO_V1(LWGEOM_line_locate_point);
+Datum LWGEOM_line_locate_point(PG_FUNCTION_ARGS)
+{
+	GSERIALIZED *geom1 = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *geom2 = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(1));
+	LWLINE *lwline;
+	LWPOINT *lwpoint;
+	POINTARRAY *pa;
+	POINT4D p, p_proj;
+	double ret;
+
+	if ( gserialized_get_type(geom1) != LINETYPE )
+	{
+		elog(ERROR,"line_locate_point: 1st arg isnt a line");
+		PG_RETURN_NULL();
+	}
+	if ( gserialized_get_type(geom2) != POINTTYPE )
+	{
+		elog(ERROR,"line_locate_point: 2st arg isnt a point");
+		PG_RETURN_NULL();
+	}
+	if ( gserialized_get_srid(geom1) != gserialized_get_srid(geom2) )
+	{
+		elog(ERROR, "Operation on two geometries with different SRIDs");
+		PG_RETURN_NULL();
+	}
+
+	lwline = lwgeom_as_lwline(lwgeom_from_gserialized(geom1));
+	lwpoint = lwgeom_as_lwpoint(lwgeom_from_gserialized(geom2));
+
+	pa = lwline->points;
+	lwpoint_getPoint4d_p(lwpoint, &p);
+
+	ret = ptarray_locate_point(pa, &p, NULL, &p_proj);
+
+	PG_RETURN_FLOAT8(ret);
+}
+
+
+/***********************************************************************
+* LEGACY SUPPORT FOR locate_between_measures and locate_along_measure
+* Deprecated at PostGIS 2.0. To be removed.
+*/
+
 
 typedef struct
 {
@@ -70,7 +299,7 @@ clip_seg_by_m_range(POINT4D *p1, POINT4D *p2, double m0, double m1)
 	int swapped=0;
 	int ret=0;
 
-	LWDEBUGF(3, "m0: %g m1: %g", m0, m1);
+	POSTGIS_DEBUGF(3, "m0: %g m1: %g", m0, m1);
 
 	/* Handle corner case of m values being the same */
 	if ( p1->m == p2->m )
@@ -124,9 +353,9 @@ clip_seg_by_m_range(POINT4D *p1, POINT4D *p2, double m0, double m1)
 	dY=p2->y-p1->y;
 	dZ=p2->z-p1->z;
 
-	LWDEBUGF(3, "dM0:%g dM1:%g", dM0, dM1);
-	LWDEBUGF(3, "dX:%g dY:%g dZ:%g", dX, dY, dZ);
-	LWDEBUGF(3, "swapped: %d", swapped);
+	POSTGIS_DEBUGF(3, "dM0:%g dM1:%g", dM0, dM1);
+	POSTGIS_DEBUGF(3, "dX:%g dY:%g dZ:%g", dX, dY, dZ);
+	POSTGIS_DEBUGF(3, "swapped: %d", swapped);
 
 	/*
 	 * First point out of range, project
@@ -142,7 +371,7 @@ clip_seg_by_m_range(POINT4D *p1, POINT4D *p2, double m0, double m1)
 		{
 			memcpy(p1, p2, sizeof(POINT4D));
 
-			LWDEBUG(3, "Projected p1 on range (as copy of p2)");
+			POSTGIS_DEBUG(3, "Projected p1 on range (as copy of p2)");
 		}
 		else
 		{
@@ -152,7 +381,7 @@ clip_seg_by_m_range(POINT4D *p1, POINT4D *p2, double m0, double m1)
 			p1->z += (dZ*dM0);
 			p1->m = m0;
 
-			LWDEBUG(3, "Projected p1 on range");
+			POSTGIS_DEBUG(3, "Projected p1 on range");
 		}
 
 		if ( swapped ) ret |= 0x0100;
@@ -173,7 +402,7 @@ clip_seg_by_m_range(POINT4D *p1, POINT4D *p2, double m0, double m1)
 		{
 			memcpy(p2, p1, sizeof(POINT4D));
 
-			LWDEBUG(3, "Projected p2 on range (as copy of p1)");
+			POSTGIS_DEBUG(3, "Projected p2 on range (as copy of p1)");
 		}
 		else
 		{
@@ -183,7 +412,7 @@ clip_seg_by_m_range(POINT4D *p1, POINT4D *p2, double m0, double m1)
 			p2->z += (dZ*dM1);
 			p2->m = m1;
 
-			LWDEBUG(3, "Projected p2 on range");
+			POSTGIS_DEBUG(3, "Projected p2 on range");
 		}
 
 		if ( swapped ) ret |= 0x0010;
@@ -199,7 +428,7 @@ static POINTARRAYSET
 ptarray_locate_between_m(POINTARRAY *ipa, double m0, double m1)
 {
 	POINTARRAYSET ret;
-	DYNPTARRAY *dpa=NULL;
+	POINTARRAY *dpa=NULL;
 	int i;
 
 	ret.nptarrays=0;
@@ -213,7 +442,7 @@ ptarray_locate_between_m(POINTARRAY *ipa, double m0, double m1)
 	 */
 	ret.ptarrays=lwalloc(sizeof(POINTARRAY *)*ipa->npoints-1);
 
-	LWDEBUGF(2, "ptarray_locate...: called for pointarray %x, m0:%g, m1:%g",
+	POSTGIS_DEBUGF(2, "ptarray_locate...: called for pointarray %x, m0:%g, m1:%g",
 	         ipa, m0, m1);
 
 
@@ -225,7 +454,7 @@ ptarray_locate_between_m(POINTARRAY *ipa, double m0, double m1)
 		getPoint4d_p(ipa, i-1, &p1);
 		getPoint4d_p(ipa, i, &p2);
 
-		LWDEBUGF(3, " segment %d-%d [ %g %g %g %g -  %g %g %g %g ]",
+		POSTGIS_DEBUGF(3, " segment %d-%d [ %g %g %g %g -  %g %g %g %g ]",
 		         i-1, i,
 		         p1.x, p1.y, p1.z, p1.m,
 		         p2.x, p2.y, p2.z, p2.m);
@@ -235,33 +464,32 @@ ptarray_locate_between_m(POINTARRAY *ipa, double m0, double m1)
 		/* segment completely outside, nothing to do */
 		if (! clipval ) continue;
 
-		LWDEBUGF(3, " clipped to: [ %g %g %g %g - %g %g %g %g ]   clipval: %x", p1.x, p1.y, p1.z, p1.m,
+		POSTGIS_DEBUGF(3, " clipped to: [ %g %g %g %g - %g %g %g %g ]   clipval: %x", p1.x, p1.y, p1.z, p1.m,
 		         p2.x, p2.y, p2.z, p2.m, clipval);
 
 		/* If no points have been accumulated so far, then if clipval != 0 the first point must be the
 		   start of the intersection */
 		if (dpa == NULL)
 		{
-			LWDEBUGF(3, " 1 creating new POINTARRAY with first point %g,%g,%g,%g", p1.x, p1.y, p1.z, p1.m);
+			POSTGIS_DEBUGF(3, " 1 creating new POINTARRAY with first point %g,%g,%g,%g", p1.x, p1.y, p1.z, p1.m);
 
-			dpa = dynptarray_create(ipa->npoints-i, ipa->dims);
-			dynptarray_addPoint4d(dpa, &p1, 1);
+			dpa = ptarray_construct_empty(FLAGS_GET_Z(ipa->flags), FLAGS_GET_M(ipa->flags), ipa->npoints-i);
+			ptarray_append_point(dpa, &p1, LW_TRUE);
 		}
 
 		/* Otherwise always add the next point, avoiding duplicates */
 		if (dpa)
-			dynptarray_addPoint4d(dpa, &p2, 0);
+			ptarray_append_point(dpa, &p2, LW_FALSE);
 
 		/*
 		 * second point has been clipped
 		 */
 		if ( clipval & 0x0100 || i == ipa->npoints-1 )
 		{
-			LWDEBUGF(3, " closing pointarray %x with %d points", dpa->pa, dpa->pa->npoints);
+			POSTGIS_DEBUGF(3, " closing pointarray %x with %d points", dpa, dpa->npoints);
 
-			ret.ptarrays[ret.nptarrays++] = dpa->pa;
-			lwfree(dpa);
-			dpa=NULL;
+			ret.ptarrays[ret.nptarrays++] = dpa;
+			dpa = NULL;
 		}
 	}
 
@@ -284,18 +512,18 @@ lwpoint_locate_between_m(LWPOINT *lwpoint, double m0, double m1)
 {
 	POINT3DM p3dm;
 
-	LWDEBUGF(2, "lwpoint_locate_between called for lwpoint %x", lwpoint);
+	POSTGIS_DEBUGF(2, "lwpoint_locate_between called for lwpoint %x", lwpoint);
 
 	lwpoint_getPoint3dm_p(lwpoint, &p3dm);
 	if ( p3dm.m >= m0 && p3dm.m <= m1)
 	{
-		LWDEBUG(3, " lwpoint... returning a clone of input");
+		POSTGIS_DEBUG(3, " lwpoint... returning a clone of input");
 
 		return (LWGEOM *)lwpoint_clone(lwpoint);
 	}
 	else
 	{
-		LWDEBUG(3, " lwpoint... returning a clone of input");
+		POSTGIS_DEBUG(3, " lwpoint... returning a clone of input");
 
 		return NULL;
 	}
@@ -325,9 +553,9 @@ lwline_locate_between_m(LWLINE *lwline_in, double m0, double m1)
 	const int lineflag=0x10;
 	POINTARRAYSET paset=ptarray_locate_between_m(ipa, m0, m1);
 
-	LWDEBUGF(2, "lwline_locate_between called for lwline %x", lwline_in);
+	POSTGIS_DEBUGF(2, "lwline_locate_between called for lwline %x", lwline_in);
 
-	LWDEBUGF(3, " ptarray_locate... returned %d pointarrays",
+	POSTGIS_DEBUGF(3, " ptarray_locate... returned %d pointarrays",
 	         paset.nptarrays);
 
 	if ( paset.nptarrays == 0 )
@@ -348,16 +576,7 @@ lwline_locate_between_m(LWLINE *lwline_in, double m0, double m1)
 		/* This is a point */
 		if ( pa->npoints == 1 )
 		{
-			lwpoint=lwalloc(sizeof(LWPOINT));
-			lwpoint->type=lwgeom_makeType_full(
-			                  TYPE_HASZ(pa->dims),
-			                  TYPE_HASM(pa->dims),
-			                  lwline_in->SRID,
-			                  POINTTYPE,
-			                  0);
-			lwpoint->SRID=lwline_in->SRID;
-			lwpoint->bbox=NULL;
-			lwpoint->point=pa;
+			lwpoint = lwpoint_construct(lwline_in->srid, NULL, pa);
 			geoms[i]=(LWGEOM *)lwpoint;
 			typeflag|=pointflag;
 		}
@@ -365,16 +584,7 @@ lwline_locate_between_m(LWLINE *lwline_in, double m0, double m1)
 		/* This is a line */
 		else if ( pa->npoints > 1 )
 		{
-			lwline=lwalloc(sizeof(LWLINE));
-			lwline->type=lwgeom_makeType_full(
-			                 TYPE_HASZ(pa->dims),
-			                 TYPE_HASM(pa->dims),
-			                 lwline_in->SRID,
-			                 LINETYPE,
-			                 0);
-			lwline->SRID=lwline_in->SRID;
-			lwline->bbox=NULL;
-			lwline->points=pa;
+			lwline = lwline_construct(lwline_in->srid, NULL, pa);
 			geoms[i]=(LWGEOM *)lwline;
 			typeflag|=lineflag;
 		}
@@ -399,7 +609,7 @@ lwline_locate_between_m(LWLINE *lwline_in, double m0, double m1)
 		else outtype = COLLECTIONTYPE;
 
 		return (LWGEOM *)lwcollection_construct(outtype,
-		                                        lwline_in->SRID, NULL, ngeoms, geoms);
+		                                        lwline_in->srid, NULL, ngeoms, geoms);
 	}
 }
 
@@ -414,7 +624,7 @@ lwcollection_locate_between_m(LWCOLLECTION *lwcoll, double m0, double m1)
 	int ngeoms=0;
 	LWGEOM **geoms;
 
-	LWDEBUGF(2, "lwcollection_locate_between_m called for lwcoll %x", lwcoll);
+	POSTGIS_DEBUGF(2, "lwcollection_locate_between_m called for lwcoll %x", lwcoll);
 
 	geoms=lwalloc(sizeof(LWGEOM *)*lwcoll->ngeoms);
 	for (i=0; i<lwcoll->ngeoms; i++)
@@ -428,7 +638,7 @@ lwcollection_locate_between_m(LWCOLLECTION *lwcoll, double m0, double m1)
 	if ( ngeoms == 0 ) return NULL;
 
 	return (LWGEOM *)lwcollection_construct(COLLECTIONTYPE,
-	                                        lwcoll->SRID, NULL, ngeoms, geoms);
+	                                        lwcoll->srid, NULL, ngeoms, geoms);
 }
 
 /*
@@ -443,9 +653,9 @@ lwcollection_locate_between_m(LWCOLLECTION *lwcoll, double m0, double m1)
 static LWGEOM *
 lwgeom_locate_between_m(LWGEOM *lwin, double m0, double m1)
 {
-	LWDEBUGF(2, "lwgeom_locate_between called for lwgeom %x", lwin);
+	POSTGIS_DEBUGF(2, "lwgeom_locate_between called for lwgeom %x", lwin);
 
-	switch (TYPE_GETTYPE(lwin->type))
+	switch (lwin->type)
 	{
 	case POINTTYPE:
 		return lwpoint_locate_between_m(
@@ -479,26 +689,31 @@ lwgeom_locate_between_m(LWGEOM *lwin, double m0, double m1)
  * See ISO/IEC CD 13249-3:200x(E)
  *
  */
+Datum LWGEOM_locate_between_m(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(LWGEOM_locate_between_m);
 Datum LWGEOM_locate_between_m(PG_FUNCTION_ARGS)
 {
-	PG_LWGEOM *gin = (PG_LWGEOM *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
-	PG_LWGEOM *gout;
+	GSERIALIZED *gin = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
+	GSERIALIZED *gout;
 	double start_measure = PG_GETARG_FLOAT8(1);
 	double end_measure = PG_GETARG_FLOAT8(2);
 	LWGEOM *lwin, *lwout;
+	int hasz = gserialized_has_z(gin);
+	int hasm = gserialized_has_m(gin);
 	int type;
 
+	elog(NOTICE,"ST_Locate_Between_Measures and ST_Locate_Along_Measure are deprecated. Use ST_LocateAlong and ST_LocateBetween.");	
+
 	if ( end_measure < start_measure )
 	{
 		lwerror("locate_between_m: 2nd arg must be bigger then 1st arg");
 		PG_RETURN_NULL();
 	}
-
+	
 	/*
 	 * Return error if input doesn't have a measure
 	 */
-	if ( ! lwgeom_hasM(gin->type) )
+	if ( ! hasm )
 	{
 		lwerror("Geometry argument does not have an 'M' ordinate");
 		PG_RETURN_NULL();
@@ -508,7 +723,7 @@ Datum LWGEOM_locate_between_m(PG_FUNCTION_ARGS)
 	 * Raise an error if input is a polygon, a multipolygon
 	 * or a collection
 	 */
-	type=lwgeom_getType(gin->type);
+	type = gserialized_get_type(gin);
 
 	if ( type == POLYGONTYPE || type == MULTIPOLYGONTYPE || type == COLLECTIONTYPE )
 	{
@@ -516,63 +731,21 @@ Datum LWGEOM_locate_between_m(PG_FUNCTION_ARGS)
 		PG_RETURN_NULL();
 	}
 
-	lwin = pglwgeom_deserialize(gin);
+	lwin = lwgeom_from_gserialized(gin);
 
 	lwout = lwgeom_locate_between_m(lwin,
 	                                start_measure, end_measure);
 
-	lwgeom_release(lwin);
+	lwgeom_free(lwin);
 
 	if ( lwout == NULL )
 	{
-		lwout = (LWGEOM *)lwcollection_construct_empty(
-		            pglwgeom_getSRID(gin), lwgeom_hasZ(gin->type),
-		            lwgeom_hasM(gin->type));
+		lwout = (LWGEOM *)lwcollection_construct_empty(COLLECTIONTYPE, 
+		            gserialized_get_srid(gin), hasz, hasm);
 	}
 
-	gout = pglwgeom_serialize(lwout);
-	lwgeom_release(lwout);
-
-	PG_RETURN_POINTER(gout);
-}
-
-
-/*
-* CREATE OR REPLACE FUNCTION ST_AddMeasure(geometry, float8, float8)
-* RETURNS geometry
-* AS '$libdir/postgis-1.5', 'ST_AddMeasure'
-* LANGUAGE 'c' IMMUTABLE STRICT;
-*/
-PG_FUNCTION_INFO_V1(ST_AddMeasure);
-Datum ST_AddMeasure(PG_FUNCTION_ARGS)
-{
-	PG_LWGEOM *gin = (PG_LWGEOM *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
-	PG_LWGEOM *gout;
-	double start_measure = PG_GETARG_FLOAT8(1);
-	double end_measure = PG_GETARG_FLOAT8(2);
-	LWGEOM *lwin, *lwout;
-	int type = TYPE_GETTYPE(gin->type);
-
-	/* Raise an error if input is not a linestring or multilinestring */
-	if ( type != LINETYPE && type != MULTILINETYPE )
-	{
-		lwerror("Only LINESTRING and MULTILINESTRING are supported");
-		PG_RETURN_NULL();
-	}
-
-	lwin = pglwgeom_deserialize(gin);
-	if ( type == LINETYPE )
-		lwout = (LWGEOM*)lwline_measured_from_lwline((LWLINE*)lwin, start_measure, end_measure);
-	else
-		lwout = (LWGEOM*)lwmline_measured_from_lwmline((LWMLINE*)lwin, start_measure, end_measure);
-
-	lwgeom_release(lwin);
-
-	if ( lwout == NULL )
-		PG_RETURN_NULL();
-
-	gout = pglwgeom_serialize(lwout);
-	lwgeom_release(lwout);
+	gout = geometry_serialize(lwout);
+	lwgeom_free(lwout);
 
 	PG_RETURN_POINTER(gout);
 }
