@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: lwgeom_in_gml.c 10767 2012-11-29 22:33:21Z colivier $
+ * $Id: lwgeom_in_gml.c 12362 2014-03-26 10:20:53Z colivier $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.refractions.net
@@ -1335,6 +1335,10 @@ static LWGEOM* parse_gml_patch(xmlNodePtr xnode, bool *hasz, int *root_srid)
 		}
 	}
 
+	/* Interior but no Exterior ! */ 
+	if ( ! ppa )
+ 		gml_lwerror("invalid GML representation", 48);
+
 	/* PolygonPatch/interior */
 	for (ring=1, xa = xnode->children ; xa != NULL ; xa = xa->next)
 	{
