@@ -2,7 +2,7 @@
  * $Id:$
  *
  * PostGIS - Spatial Types for PostgreSQL
- * http://postgis.refractions.net
+
  * Copyright 2009 Oslandia
  *
  * This is free software; you can redistribute and/or modify it under
@@ -27,19 +27,22 @@
 **********************************************************************/
 
 
+#include <libxml/tree.h>
+#include <libxml/parser.h>
+#include <errno.h>
+#include <string.h>
+
 #include "postgres.h"
+
+#include "../postgis_config.h"
 #include "lwgeom_pg.h"
 #include "liblwgeom.h"
 
 
-#include <libxml/tree.h>
-#include <libxml/parser.h>
-
 
 /*
 TODO:
 	- OGC:LonLat84_5773 explicit support (rather than EPSG:4326)
-	- Don't return a GEOMETRYCOLLECTION if a MULTI one is enough
 	- altitudeModeGroup relativeToGround Z Altitude
 	  computation upon Geoid
 */
@@ -58,14 +61,12 @@ static LWGEOM* parse_kml(xmlNodePtr xnode, bool *hasz);
 PG_FUNCTION_INFO_V1(geom_from_kml);
 Datum geom_from_kml(PG_FUNCTION_ARGS)
 {
-	PG_LWGEOM *geom, *geom2d;
+	GSERIALIZED *geom;
+	LWGEOM *lwgeom, *hlwgeom;
 	xmlDocPtr xmldoc;
 	text *xml_input;
-	LWGEOM *lwgeom;
 	int xml_size;
-	uchar *srl;
 	char *xml;
-	size_t size=0;
 	bool hasz=true;
 	xmlNodePtr xmlroot=NULL;
 
@@ -73,15 +74,12 @@ Datum geom_from_kml(PG_FUNCTION_ARGS)
 	/* Get the KML stream */
 	if (PG_ARGISNULL(0)) PG_RETURN_NULL();
 	xml_input = PG_GETARG_TEXT_P(0);
-
-	xml_size = VARSIZE(xml_input) - VARHDRSZ; 	/* actual letters */
-	xml = palloc(xml_size + 1); 			/* +1 for null */
-	memcpy(xml, VARDATA(xml_input), xml_size);
-	xml[xml_size] = 0; 				/* null term */
+	xml = text2cstring(xml_input);
+	xml_size = VARSIZE(xml_input) - VARHDRSZ;
 
 	/* Begin to Parse XML doc */
 	xmlInitParser();
-	xmldoc = xmlParseMemory(xml, xml_size);
+	xmldoc = xmlReadMemory(xml, xml_size, NULL, NULL, XML_PARSE_SAX1);
 	if (!xmldoc || (xmlroot = xmlDocGetRootElement(xmldoc)) == NULL)
 	{
 		xmlFreeDoc(xmldoc);
@@ -90,12 +88,16 @@ Datum geom_from_kml(PG_FUNCTION_ARGS)
 	}
 
 	lwgeom = parse_kml(xmlroot, &hasz);
-	lwgeom->bbox = lwgeom_compute_box2d(lwgeom);
-	geom = pglwgeom_serialize(lwgeom);
-	lwgeom_release(lwgeom);
 
-	xmlFreeDoc(xmldoc);
-	xmlCleanupParser();
+	/* Homogenize geometry result if needed */
+	if (lwgeom->type == COLLECTIONTYPE)
+	{
+		hlwgeom = lwgeom_homogenize(lwgeom);
+		lwgeom_release(lwgeom);
+		lwgeom = hlwgeom;
+	}
+
+	lwgeom_add_bbox(lwgeom);
 
 	/* KML geometries could be either 2 or 3D
 	 *
@@ -105,14 +107,17 @@ Datum geom_from_kml(PG_FUNCTION_ARGS)
 	 */
 	if (!hasz)
 	{
-		srl = lwalloc(VARSIZE(geom));
-		lwgeom_force2d_recursive(SERIALIZED_FORM(geom), srl, &size);
-		geom2d = PG_LWGEOM_construct(srl, pglwgeom_getSRID(geom),
-		                             lwgeom_hasBBOX(geom->type));
-		lwfree(geom);
-		geom = geom2d;
+		LWGEOM *tmp = lwgeom_force_2d(lwgeom);
+		lwgeom_free(lwgeom);
+		lwgeom = tmp;
 	}
 
+	geom = geometry_serialize(lwgeom);
+	lwgeom_free(lwgeom);
+
+	xmlFreeDoc(xmldoc);
+	xmlCleanupParser();
+
 	PG_RETURN_POINTER(geom);
 }
 
@@ -133,23 +138,26 @@ static bool is_kml_namespace(xmlNodePtr xnode, bool is_strict)
 	 */
 	if (ns == NULL) return !is_strict;
 
-	for (p=ns ; *p ; p++)
-	{
-		if ((*p)->href == NULL) continue;
-		if (!strcmp((char *) (*p)->href, KML_NS))
-		{
-			if (	(*p)->prefix == NULL ||
-			        !xmlStrcmp(xnode->ns->prefix, (*p)->prefix))
-			{
+        for (p=ns ; *p ; p++)
+        {
+                if ((*p)->href == NULL || (*p)->prefix == NULL ||
+                     xnode->ns == NULL || xnode->ns->prefix == NULL) continue;
 
-				xmlFree(ns);
-				return true;
-			}
-		}
-	}
+                if (!xmlStrcmp(xnode->ns->prefix, (*p)->prefix))
+                {
+                        if (!strcmp((char *) (*p)->href, KML_NS))
+                        {
+                                xmlFree(ns);
+                                return true;
+                        } else {
+                                xmlFree(ns);
+                                return false;
+                        }
+                }
+        }
 
-	xmlFree(ns);
-	return false;
+        xmlFree(ns);
+        return !is_strict; /* Same reason here to not return false */;
 }
 
 
@@ -176,6 +184,7 @@ static xmlChar *kmlGetProp(xmlNodePtr xnode, xmlChar *prop)
 #endif
 
 
+#if 0 /* unused */
 /**
  * Parse a string supposed to be a double
  */
@@ -207,6 +216,8 @@ static double parse_kml_double(char *d, bool space_before, bool space_after)
 	for (st = INIT, p = d ; *p ; p++)
 	{
 
+lwnotice("State: %d, *p=%c", st, *p);
+
 		if (isdigit(*p))
 		{
 			if (st == INIT || st == NEED_DIG) 	st = DIG;
@@ -247,6 +258,7 @@ static double parse_kml_double(char *d, bool space_before, bool space_after)
 
 	return atof(d);
 }
+#endif /* unused */
 
 
 /**
@@ -255,13 +267,12 @@ static double parse_kml_double(char *d, bool space_before, bool space_after)
 static POINTARRAY* parse_kml_coordinates(xmlNodePtr xnode, bool *hasz)
 {
 	xmlChar *kml_coord;
-	bool digit, found;
-	DYNPTARRAY *dpa;
-	POINTARRAY *pa;
+	bool found;
+	POINTARRAY *dpa;
 	int kml_dims;
 	char *p, *q;
 	POINT4D pt;
-	uchar dims=0;
+  double d;
 
 	if (xnode == NULL) lwerror("invalid KML representation");
 
@@ -285,57 +296,53 @@ static POINTARRAY* parse_kml_coordinates(xmlNodePtr xnode, bool *hasz)
 	*/
 
 	/* Now we create PointArray from coordinates values */
-	TYPE_SETZM(dims, 1, 0);
-	dpa = dynptarray_create(1, dims);
+	/* HasZ, !HasM, 1pt */
+	dpa = ptarray_construct_empty(1, 0, 1);
 
-	for (q = p, kml_dims=0, digit = false ; *p ; p++)
+  while (*p && isspace(*p)) ++p;
+	for (kml_dims=0; *p ; p++)
 	{
+//lwnotice("*p:%c, kml_dims:%d", *p, kml_dims);
+    if ( isdigit(*p) || *p == '+' || *p == '-' || *p == '.' ) {
+			  kml_dims++;
+        errno = 0; d = strtod(p, &q);
+        if ( errno != 0 ) {
+          // TODO: destroy dpa, return NULL
+          lwerror("invalid KML representation"); /*: %s", strerror(errno));*/
+        }
+        if      (kml_dims == 1) pt.x = d;
+        else if (kml_dims == 2) pt.y = d;
+        else if (kml_dims == 3) pt.z = d;
+        else {
+          lwerror("invalid KML representation"); /* (more than 3 dimensions)"); */
+          // TODO: destroy dpa, return NULL
+        }
 
-		if (isdigit(*p)) digit = true;  /* One state parser */
+//lwnotice("after strtod d:%f, *q:%c, kml_dims:%d", d, *q, kml_dims);
 
-		/* Coordinate Separator */
-		if (*p == ',')
-		{
-			*p = '\0';
-			kml_dims++;
+        if ( *q && ! isspace(*q) && *q != ',' ) {
+          lwerror("invalid KML representation"); /* (invalid character %c follows ordinate value)", *q); */
+        }
 
-			if (*(p+1) == '\0') lwerror("invalid KML representation");
-
-			if      (kml_dims == 1) pt.x = parse_kml_double(q, true, true);
-			else if (kml_dims == 2) pt.y = parse_kml_double(q, true, true);
-			q = p+1;
-
-			/* Tuple Separator (or end string) */
-		}
-		else if (digit && (isspace(*p) || *(p+1) == '\0'))
-		{
-			if (isspace(*p)) *p = '\0';
-			kml_dims++;
-
-			if (kml_dims < 2 || kml_dims > 3)
-				lwerror("invalid KML representation");
-
-			if (kml_dims == 3)
-				pt.z = parse_kml_double(q, true, true);
-			else
-			{
-				pt.y = parse_kml_double(q, true, true);
-				*hasz = false;
-			}
-
-			dynptarray_addPoint4d(dpa, &pt, 0);
-			digit = false;
-			q = p+1;
-			kml_dims = 0;
-
-		}
+        /* Look-ahead to see if we're done reading */
+        while (*q && isspace(*q)) ++q;
+        if ( isdigit(*q) || *q == '+' || *q == '-' || *q == '.' || ! *q ) {
+          if ( kml_dims < 2 ) lwerror("invalid KML representation"); /* (not enough ordinates)"); */
+          if ( kml_dims < 3 ) *hasz = false;
+          ptarray_append_point(dpa, &pt, LW_FALSE);
+          kml_dims = 0;
+        }
+        p = q-1; /* will be incrementedon next iteration */
+//lwnotice("after look-ahead *p:%c, kml_dims:%d", *p, kml_dims);
+    } else if ( *p != ',' && ! isspace(*p) ) {
+          lwerror("invalid KML representation"); /* (unexpected character %c)", *p); */
+    }
 	}
 
 	xmlFree(kml_coord);
-	pa = ptarray_clone(dpa->pa);
-	lwfree(dpa);
 
-	return pa;
+	/* TODO: we shouldn't need to clone here */
+	return ptarray_clone_deep(dpa);
 }
 
 
@@ -397,8 +404,8 @@ static LWGEOM* parse_kml_polygon(xmlNodePtr xnode, bool *hasz)
 			ppa[0] = parse_kml_coordinates(xb->children, hasz);
 
 			if (ppa[0]->npoints < 4
-			        || (!*hasz && !ptarray_isclosed2d(ppa[0]))
-			        ||  (*hasz && !ptarray_isclosed3d(ppa[0])))
+			        || (!*hasz && !ptarray_is_closed_2d(ppa[0]))
+			        ||  (*hasz && !ptarray_is_closed_3d(ppa[0])))
 				lwerror("invalid KML representation");
 		}
 	}
@@ -423,8 +430,8 @@ static LWGEOM* parse_kml_polygon(xmlNodePtr xnode, bool *hasz)
 			ppa[ring] = parse_kml_coordinates(xb->children, hasz);
 
 			if (ppa[ring]->npoints < 4
-			        || (!*hasz && !ptarray_isclosed2d(ppa[ring]))
-			        ||  (*hasz && !ptarray_isclosed3d(ppa[ring])))
+			        || (!*hasz && !ptarray_is_closed_2d(ppa[ring]))
+			        ||  (*hasz && !ptarray_is_closed_3d(ppa[ring])))
 				lwerror("invalid KML representation");
 
 			ring++;
@@ -446,7 +453,7 @@ static LWGEOM* parse_kml_multi(xmlNodePtr xnode, bool *hasz)
 	LWGEOM *geom;
 	xmlNodePtr xa;
 
-	geom = (LWGEOM *)lwcollection_construct_empty(4326, 1, 0);
+	geom = (LWGEOM *)lwcollection_construct_empty(COLLECTIONTYPE, 4326, 1, 0);
 
 	for (xa = xnode->children ; xa != NULL ; xa = xa->next)
 	{
@@ -461,8 +468,7 @@ static LWGEOM* parse_kml_multi(xmlNodePtr xnode, bool *hasz)
 		{
 
 			if (xa->children == NULL) break;
-			geom = lwcollection_add((LWCOLLECTION *)geom, -1,
-			                        parse_kml(xa, hasz));
+			geom = (LWGEOM*)lwcollection_add_lwgeom((LWCOLLECTION*)geom, parse_kml(xa, hasz));
 		}
 	}
 
