@@ -1,11 +1,22 @@
+/**********************************************************************
+ *
+ * PostGIS - Spatial Types for PostgreSQL
+ * http://postgis.refractions.net
+ *
+ * Copyright (C) 2004 Refractions Research Inc.
+ *
+ * This is free software; you can redistribute and/or modify it under
+ * the terms of the GNU General Public Licence. See the COPYING file.
+ *
+ **********************************************************************/
+
 #include "postgres.h"
 #include "executor/spi.h"       /* this is what you need to work with SPI */
 #include "commands/trigger.h"   /* ... and triggers */
-#include "lwgeom_pg.h"
 
-#if POSTGIS_PGSQL_VERSION >= 92
+#include "../postgis_config.h"
+#include "lwgeom_pg.h"
 #include "utils/rel.h"
-#endif
 
 Datum cache_bbox(PG_FUNCTION_ARGS);
 
