@@ -1,5 +1,5 @@
 /*
- * $Id: rt_api.h 12060 2013-10-28 19:44:03Z dustymugs $
+ * $Id: rt_api.h 12336 2014-03-22 05:29:54Z robe $
  *
  * WKTRaster - Raster Types for PostGIS
  * http://www.postgis.org/support/wiki/index.php?WKTRasterHomePage
@@ -42,7 +42,7 @@
 #endif
 
 
-#if defined(__FreeBSD__) || defined(__OpenBSD__)    /* seems to work like Linux... */
+#if defined(__FreeBSD_kernel__) || defined(__OpenBSD__)    /* seems to work like Linux... */
 #if !defined(LINUX)
 #define LINUX
 #endif
