@@ -200,16 +200,6 @@ else
 	}
 }
 
-if ( $OPT_UPGRADE )
-{
-	upgrade_spatial();
-}
-
-
-##################################################################
-# Report PostGIS environment
-##################################################################
-
 my $libver = sql("select postgis_lib_version()");
 
 if ( ! $libver )
@@ -220,6 +210,24 @@ if ( ! $libver )
 	exit(1);
 }
 
+
+if ( $OPT_UPGRADE )
+{
+	if ( $OPT_EXTENSIONS )
+	{	
+		upgrade_spatial_extensions();
+	}
+	else
+	{
+	  upgrade_spatial();
+  }
+}
+
+
+##################################################################
+# Report PostGIS environment
+##################################################################
+
 my $geosver =  sql("select postgis_geos_version()");
 my $projver = sql("select postgis_proj_version()");
 my $svnrev = sql("select postgis_svn_version()");
@@ -540,7 +548,21 @@ sub run_simple_test
 	mkpath($betmpdir);
 	chmod 0777, $betmpdir;
 
-	my $cmd = "psql -v \"VERBOSITY=terse\" -v \"tmpfile='$tmpfile'\" -tXA $DB < $sql > $outfile 2>&1";
+	my $scriptdir;
+	if ( $OPT_EXTENSIONS ) {
+		# TODO: allow override this default with env variable ?
+		my $pgis_majmin = $libver;
+		$pgis_majmin =~ s/^([1-9]*\.[1-9]*).*/\1/;
+		$scriptdir = `pg_config --sharedir`;
+		chop $scriptdir;
+		$scriptdir .= "/contrib/postgis-" . $pgis_majmin;
+	} else {
+		$scriptdir = $STAGED_SCRIPTS_DIR;
+	}
+	my $cmd = "psql -v \"VERBOSITY=terse\""
+          . " -v \"tmpfile='$tmpfile'\""
+          . " -v \"scriptdir=$scriptdir\""
+          . " -tXA $DB < $sql > $outfile 2>&1";
 	my $rv = system($cmd);
 
 	# Check for ERROR lines
@@ -1111,6 +1133,29 @@ sub upgrade_spatial
     return 1;
 }
 
+# Upgrade an existing database (soft upgrade, extension method)
+sub upgrade_spatial_extensions
+{
+    print "Upgrading PostGIS in '${DB}' using 'ALTER EXTENSION'\n" ;
+
+    # ON_ERROR_STOP is used by psql to return non-0 on an error
+    my $psql_opts = "--no-psqlrc --variable ON_ERROR_STOP=true";
+    my $cmd = "psql $psql_opts -c \"ALTER EXTENSION postgis UPDATE TO '${libver}next'\" $DB >> $REGRESS_LOG 2>&1";
+    my $rv = system($cmd);
+    die "\nError encountered altering EXTENSION POSTGIS, see $REGRESS_LOG for details\n\n"
+	    if $rv;
+
+    if ( $OPT_WITH_TOPO ) 
+    {
+      my $cmd = "psql $psql_opts -c \"ALTER EXTENSION postgis_topology UPDATE TO '${libver}next'\" $DB >> $REGRESS_LOG 2>&1";
+      my $rv = system($cmd);
+      die "\nError encountered altering EXTENSION POSTGIS_TOPOLOGY, see $REGRESS_LOG for details\n\n"
+        if $rv;
+    }
+    
+    return 1;
+}
+
 sub drop_spatial
 {
 	my $ok = 1;
