@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: test_joinestimation.pl,v 1.3 2005/04/18 13:50:14 strk Exp $
+# $Id: test_joinestimation.pl 9324 2012-02-27 22:08:12Z pramsey $
 # 
 # TODO:
 #
@@ -221,8 +221,7 @@ sub get_geometry_type
 		exit(1);
 	}
 	if ( $res->ntuples() > 1 ) {
-		print STDERR "Mixed geometry types in \"$SCHEMA1\".\"$TABLE1\".\"$COLUMN1\"\n";
-		exit(1);
+		print STDERR "WARNING: Mixed geometry types in \"$SCHEMA1\".\"$TABLE1\".\"$COLUMN1\"\n";
 	}
 	return $res->getvalue(0, 0);
 }
@@ -255,7 +254,7 @@ sub get_num_rows
 }
 
 # 
-# $Log: test_joinestimation.pl,v $
+# $Log$
 # Revision 1.3  2005/04/18 13:50:14  strk
 # Fixed bug in table2 schema parsing.
 #
